.. _github-stats-3-1-0:

GitHub Stats for Matplotlib 3.1.0
=================================

GitHub stats for 2018/09/18 - 2019/05/13 (tag: v3.0.0)

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 161 issues and merged 918 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestones/v3.1.0>`__

The following 150 authors contributed 3426 commits.

* Abhinuv Nitin Pitale
* Adam J. Stewart
* Alistair Muldal
* Alon Hershenhorn
* Andras Deak
* Ankur Dedania
* Antony Lee
* Anubhav Shrimal
* Ao Liu (frankliuao)
* Ayappan P
* azure-pipelines[bot]
* Bas van Schaik
* Ben Root
* Benjamin Bengfort
* Benjamin Congdon
* Bharat123rox
* Brigitta Sipocz
* btang02
* Carsten
* Carsten Schelp
* Cho Yin Yong
* Chris Zimmerman
* Christer Jensen
* Christoph Gohlke
* Christoph Reiter
* Christopher Bradshaw
* Colin
* Colin Carroll
* dabana
* Dana-Farber
* Daniele Nicolodi
* DanielMatu
* David Haberthür
* David Stansby
* Dietmar Schwertberger
* Dmitry Mottl
* E\. G\. Patrick Bos
* Elan Ernest
* Elliott Sales de Andrade
* Eric Firing
* Eric Larson
* Eric Wieser
* esvhd
* fredrik-1
* fuzzythecat
* Galen Lynch
* Gazing
* gwin-zegal
* hannah
* Harshal Prakash Patankar
* hershen
* Ildar Akhmetgaleev
* ImportanceOfBeingErnest
* Isa Hassen
* Jae-Joon Lee
* James A. Bednar
* James Adams
* Jan S. (Milania1)
* Jarrod Millman
* Jessica B. Hamrick
* Jody Klymak
* Joel T. Frederico
* Joel Wanner
* Johannes H. Jensen
* Joseph Albert
* Joshua Klein
* Jouni K. Seppänen
* Jun Tan
* Kai Muehlbauer
* Katrin Leinweber
* Kayla Ngan
* Kevin Rose
* Kjell Le
* KonradAdamczyk
* ksunden
* Kyle Sunden
* Leon Loopik
* Levi Kilcher
* LevN0
* luftek
* Maik Riechert
* Marcel Martin
* Mark Harfouche
* Marko Baštovanović
* Matthias Bussonnier
* Matthias Geier
* Matti Picus
* MeeseeksMachine
* Michael Droettboom
* Michael Jancsy
* Mike Frysinger
* Molly Rossow
* MortenSHUTE
* mromanie
* nathan78906
* Nelle Varoquaux
* Nick Papior
* Nicolas Courtemanche
* Nikita Kniazev
* njwhite
* Oliver Natt
* Paul
* Paul Hobson
* Paul Ivanov
* Paul J. Koprowski
* pharshalp
* Phil Elson
* Pierre Thibault
* QiCuiHub
* Rasmus Diederichsen
* Ratin_Kumar
* Rob Harrigan
* Roman Yurchak
* Ryan May
* Ryan Morshead
* Saket Choudhary
* saksmito
* SBCV
* Sebastian Bullinger
* Sebastian Hegler
* Seunghoon Park
* simon-kraeusel
* smheidrich
* Stephane Raynaud
* Stephen-Chilcote
* sxntxn
* Taehoon Lee
* Takafumi Arakaki
* Taras
* Taras Kuzyo
* teresy
* Thein Oo
* Thomas A Caswell
* Thomas Hisch
* Thomas Robitaille
* thoo
* Tim Hoffmann
* Tobia De Koninck
* Tobias Megies
* Tyler Makaro
* V\. Armando Solé
* Viraj Mohile
* Will Handley
* woclass
* Yasaman-Mah
* yeo
* Yuxin Wu
* Yuya
* Zhili (Jerry) Pan
* zhoubecky

GitHub issues and pull requests:

Pull Requests (918):

* :ghpull:`14209`: Backport PR #14197 on branch v3.1.x (Minor cleanup of acorr/xcoor docs)
* :ghpull:`14210`: Make intro tutorial less jargony.
* :ghpull:`14197`: Minor cleanup of acorr/xcoor docs
* :ghpull:`14203`: Backport PR #14202 on branch v3.1.x (Fix docstring of Line2D.set_data.)
* :ghpull:`14202`: Fix docstring of Line2D.set_data.
* :ghpull:`14196`: Backport PR #14188 on branch v3.1.x (Clarify scope of MouseEvent attributes)
* :ghpull:`14188`: Clarify scope of MouseEvent attributes
* :ghpull:`14194`: Backport PR #14167 on branch v3.1.x (Fix backend_pgf header.)
* :ghpull:`14193`: Backport PR #14153 on branch v3.1.x (Update qt_compat.py test for already imported binding.)
* :ghpull:`14167`: Fix backend_pgf header.
* :ghpull:`14153`: Update qt_compat.py test for already imported binding.
* :ghpull:`14190`: Backport PR #14176 on branch v3.1.x (Merge doc/api/api_overview and doc/api/index.)
* :ghpull:`14192`: Unbreak testsuite for pytest 4.5.
* :ghpull:`14189`: Backport PR #14186 on branch v3.1.x (Update FancyBboxPatch docs to numpydoc style)
* :ghpull:`14176`: Merge doc/api/api_overview and doc/api/index.
* :ghpull:`14186`: Update FancyBboxPatch docs to numpydoc style
* :ghpull:`14187`: Backport PR #13169 on branch v3.1.x (Add example code for current logo)
* :ghpull:`14165`: Backport PR #14156 on branch v3.1.x (Fix glyph loading in textpath.)
* :ghpull:`14156`: Fix glyph loading in textpath.
* :ghpull:`14162`: Backport PR #14150 on branch v3.1.x (Fix deprecation of withdash for figtext().)
* :ghpull:`14150`: Fix deprecation of withdash for figtext().
* :ghpull:`14136`: Backport PR #14109 on branch v3.1.x
* :ghpull:`14109`: Some simple pyplot doc improvements
* :ghpull:`14129`: Backport PR #14117 on branch v3.1.x (Simplify ribbon_box example.)
* :ghpull:`14128`: Backport PR #14057 on branch v3.1.x (Improve Gradient bar example)
* :ghpull:`14127`: Backport PR #14125 on branch v3.1.x (Remove extra keyword from pytest.skip call.)
* :ghpull:`14117`: Simplify ribbon_box example.
* :ghpull:`14057`: Improve Gradient bar example
* :ghpull:`14125`: Remove extra keyword from pytest.skip call.
* :ghpull:`14123`: Backport PR #14119 on branch v3.1.x (Add ridge_map to third party packages documentation)
* :ghpull:`14119`: Add ridge_map to third party packages documentation
* :ghpull:`14103`: Backport PR #14088 on branch v3.1.x (Cleanup major_minor_demo.)
* :ghpull:`14102`: Backport PR #14100 on branch v3.1.x (Improve docstring of axes_zoom_effect example.)
* :ghpull:`14099`: Backport PR #14090 on branch v3.1.x (Pep8ify some variable names in examples.)
* :ghpull:`14100`: Improve docstring of axes_zoom_effect example.
* :ghpull:`14088`: Cleanup major_minor_demo.
* :ghpull:`14090`: Pep8ify some variable names in examples.
* :ghpull:`14097`: Backport PR #14079 on branch v3.1.x (Consistently use axs.flat instead of axs.flatten())
* :ghpull:`14095`: Backport PR #14087 on branch v3.1.x (Cleanup date example.)
* :ghpull:`14094`: Backport PR #14029 on branch v3.1.x (Fix doc building with numpydoc 0.9)
* :ghpull:`14093`: Backport PR #14052 on branch v3.1.x (Check axes identity in image.contains.)
* :ghpull:`14092`: Backport PR #14056 on branch v3.1.x (FIX: do not try to manage the visibility of un-drawn ticks)
* :ghpull:`14091`: Backport PR #14078 on branch v3.1.x (Minor fix in multiple subplots example)
* :ghpull:`14079`: Consistently use axs.flat instead of axs.flatten()
* :ghpull:`14087`: Cleanup date example.
* :ghpull:`14029`: Fix doc building with numpydoc 0.9
* :ghpull:`14052`: Check axes identity in image.contains.
* :ghpull:`14056`: FIX: do not try to manage the visibility of un-drawn ticks
* :ghpull:`14078`: Minor fix in multiple subplots example
* :ghpull:`14080`: Backport PR #14069 on branch v3.1.x (Don't try to use the colorbar formatter to format RGBA data.)
* :ghpull:`14069`: Don't try to use the colorbar formatter to format RGBA data.
* :ghpull:`14074`: Backport PR #14019 on branch v3.1.x (Update docstring of locator_params())
* :ghpull:`14019`: Update docstring of locator_params()
* :ghpull:`14066`: Backport PR #14053 on branch v3.1.x (Improve fill() example)
* :ghpull:`14065`: Backport PR #14059 on branch v3.1.x (Improve Scatter hist example)
* :ghpull:`14067`: Backport PR #14062 on branch v3.1.x (Improve advanced quiver example)
* :ghpull:`14062`: Improve advanced quiver example
* :ghpull:`14053`: Improve fill() example
* :ghpull:`14059`: Improve Scatter hist example
* :ghpull:`14064`: Backport PR #14043 on branch v3.1.x (Ensure errorbars are always drawn on top of bars in ax.bar)
* :ghpull:`14043`: Ensure errorbars are always drawn on top of bars in ax.bar
* :ghpull:`14061`: Backport PR #14051 on branch v3.1.x (Add Yellowbrick to third party packages)
* :ghpull:`14051`: Add Yellowbrick to third party packages
* :ghpull:`14050`: Backport PR #14048 on branch v3.1.x (Fix Animation.save)
* :ghpull:`14049`: Backport PR #14047 on branch v3.1.x (Remove references to "Draws" in matplotlib.patches)
* :ghpull:`14048`: Fix Animation.save
* :ghpull:`14047`: Remove references to "Draws" in matplotlib.patches
* :ghpull:`14037`: Backport PR #14033 on branch v3.1.x (Reword add_subplot docstring.)
* :ghpull:`14036`: Backport PR #14001 on branch v3.1.x ([BUG] DOC: Remove broken references to vischeck)
* :ghpull:`14033`: Reword add_subplot docstring.
* :ghpull:`14032`: Backport PR #14030 on branch v3.1.x (Update colorcet link)
* :ghpull:`14030`: Update colorcet link
* :ghpull:`14027`: Backport PR #14026 on branch v3.1.x (Fix bug in plot_directive that caused links to plots in different formats to be missing)
* :ghpull:`14026`: Fix bug in plot_directive that caused links to plots in different formats to be missing
* :ghpull:`14012`: Backport PR #14008 on branch v3.1.x (Don't install tests by default.)
* :ghpull:`14017`: Backport PR #14015 on branch v3.1.x (Fix docstring of pyplot.clim())
* :ghpull:`14015`: Fix docstring of pyplot.clim()
* :ghpull:`14008`: Don't install tests by default.
* :ghpull:`14006`: Backport PR #13998 on branch v3.1.x (Fix patch contains logic for patches that don't have any codes)
* :ghpull:`14005`: Backport PR #14004 on branch v3.1.x (DOC: pin numpydoc to less than 0.9)
* :ghpull:`13998`: Fix patch contains logic for patches that don't have any codes
* :ghpull:`13999`: Backport PR #13992 on branch v3.1.x (FIX: undeprecate MaxNLocator default_params)
* :ghpull:`13997`: Backport PR #13995 on branch v3.1.x (DOC: explain zorder for gridlines in grid docstring)
* :ghpull:`13992`: FIX: undeprecate MaxNLocator default_params
* :ghpull:`13995`: DOC: explain zorder for gridlines in grid docstring
* :ghpull:`13990`: Backport PR #13989 on branch v3.1.x (FIX: update not replace hist_kwargs when density is passed)
* :ghpull:`13989`: FIX: update not replace hist_kwargs when density is passed
* :ghpull:`13975`: Backport PR #13966 on branch v3.1.x (Fix colorbar setting without artist)
* :ghpull:`13976`: Backport PR #13973 on branch v3.1.x (BUG: Ensure docstrings are not accessed with -OO)
* :ghpull:`13856`: What's new page for 3.1
* :ghpull:`13966`: Fix colorbar setting without artist
* :ghpull:`13973`: BUG: Ensure docstrings are not accessed with -OO
* :ghpull:`13969`: Backport PR #13950 on branch v3.1.x (confidence_ellipse_markup)
* :ghpull:`13950`: confidence_ellipse_markup
* :ghpull:`13965`: Backport PR #13962 on branch v3.1.x (Fix typo in code example in docstring.)
* :ghpull:`13964`: Backport PR #13870 on branch v3.1.x (3.1.0 API changes page)
* :ghpull:`13962`: Fix typo in code example in docstring.
* :ghpull:`13870`: 3.1.0 API changes page
* :ghpull:`13961`: Backport PR #13914 on branch v3.1.x (Improve Rainbow text example)
* :ghpull:`13960`: Backport PR #13958 on branch v3.1.x (Remove transparent fancy legend example)
* :ghpull:`13914`: Improve Rainbow text example
* :ghpull:`13958`: Remove transparent fancy legend example
* :ghpull:`13956`: Backport PR #13908 on branch v3.1.x (Enh control tick deconflict2)
* :ghpull:`13955`: Backport PR #13941 on branch v3.1.x (Add project_urls to setup)
* :ghpull:`13908`: Enh control tick deconflict2
* :ghpull:`13954`: Backport PR #13949 on branch v3.1.x (DOC: Add documentation to Text.set_fontfamily)
* :ghpull:`13941`: Add project_urls to setup
* :ghpull:`13949`: DOC: Add documentation to Text.set_fontfamily
* :ghpull:`13951`: Backport PR #13939 on branch v3.1.x (Bunch of docstring cleanups.)
* :ghpull:`13939`: Bunch of docstring cleanups.
* :ghpull:`13947`: Backport PR #13897 on branch v3.1.x (numpydocification.)
* :ghpull:`13897`: numpydocification.
* :ghpull:`13946`: Backport PR #13924 on branch v3.1.x (Followup to deprecation of usetex parameter in get_text_path.)
* :ghpull:`13924`: Followup to deprecation of usetex parameter in get_text_path.
* :ghpull:`13916`: Backport PR #13850 on branch v3.1.x (Cleanup STIX Font Demo)
* :ghpull:`13915`: Backport PR #13835 on branch v3.1.x (Improve Conectionstyle Demo)
* :ghpull:`13850`: Cleanup STIX Font Demo
* :ghpull:`13835`: Improve Conectionstyle Demo
* :ghpull:`13846`: Backport PR #13836 on branch v3.1.x (MNT: account for cpython deprecations)
* :ghpull:`13898`: Backport PR #13896 on branch v3.1.x (Fix cbook.boxplot_stats docstring)
* :ghpull:`13896`: Fix cbook.boxplot_stats docstring
* :ghpull:`13893`: Backport PR #13890 on branch v3.1.x (rst seealso -> numpydoc "See Also".)
* :ghpull:`13890`: rst seealso -> numpydoc "See Also".
* :ghpull:`13888`: Backport PR #13862 on branch v3.1.x (Move 3.x API changes to prev_api_changes)
* :ghpull:`13862`: Move 3.x API changes to prev_api_changes
* :ghpull:`13882`: Backport PR #13867 on branch v3.1.x (Rename "docs" to "contents" in navigation bar)
* :ghpull:`13867`: Rename "docs" to "contents" in navigation bar
* :ghpull:`13881`: Backport PR #13874 on branch v3.1.x (Remove redundant call to Formatter.set_locs() before .format_ticks().)
* :ghpull:`13874`: Remove redundant call to Formatter.set_locs() before .format_ticks().
* :ghpull:`13871`: Backport PR #13868 on branch v3.1.x (Correctly handle fallout of defining PY_SSIZE_T_CLEAN on Windows.)
* :ghpull:`13869`: Backport PR #13861 on branch v3.1.x (Fix remaining links in docs)
* :ghpull:`13868`: Correctly handle fallout of defining PY_SSIZE_T_CLEAN on Windows.
* :ghpull:`13861`: Fix remaining links in docs
* :ghpull:`13849`: Backport PR #13845 on branch v3.1.x (Fix some broken documentation links)
* :ghpull:`13845`: Fix some broken documentation links
* :ghpull:`13836`: MNT: account for cpython deprecations
* :ghpull:`13841`: Backport PR #12928 on branch v3.1.x (textpath encoding)
* :ghpull:`13842`: Backport PR #13827 on branch v3.1.x (Better MovieWriter init error message)
* :ghpull:`13838`: Backport PR #13570 on branch v3.1.x (Add new example for plotting a confidence_ellipse)
* :ghpull:`13827`: Better MovieWriter init error message
* :ghpull:`13839`: Backport PR #13815 on branch v3.1.x (Numpydocify FontManager.findfont())
* :ghpull:`13837`: Backport PR #8638 on branch v3.1.x (FIX: if bins input to hist is str, treat like no bins)
* :ghpull:`12928`: textpath encoding
* :ghpull:`13815`: Numpydocify FontManager.findfont()
* :ghpull:`13570`: Add new example for plotting a confidence_ellipse
* :ghpull:`8638`: FIX: if bins input to hist is str, treat like no bins
* :ghpull:`13831`: Backport PR #13780 on branch v3.1.x (numpydoc ListedColormap parameters)
* :ghpull:`13780`: numpydoc ListedColormap parameters
* :ghpull:`13830`: Backport PR #13829 on branch v3.1.x (numpydoc IndexFormatter)
* :ghpull:`13829`: numpydoc IndexFormatter
* :ghpull:`13828`: Backport PR #13821 on branch v3.1.x (Remove \mathcircled from mathtext docs following its deprecation.)
* :ghpull:`13821`: Remove \mathcircled from mathtext docs following its deprecation.
* :ghpull:`13822`: Backport PR #13817 on branch v3.1.x (Remove borders from barcode example)
* :ghpull:`13820`: Backport PR #13816 on branch v3.1.x (Correct windows env variable format)
* :ghpull:`13816`: Correct windows env variable format
* :ghpull:`13817`: Remove borders from barcode example
* :ghpull:`13814`: Merge pull request #13805 from timhoffm/pin-sphinx-1.x
* :ghpull:`13813`: Backport PR #13764 on branch v3.1.x (Deprecate \mathcircled.)
* :ghpull:`13764`: Deprecate \mathcircled.
* :ghpull:`13805`: Pin Sphinx to 1.x
* :ghpull:`13807`: Backport PR #13800 on branch v3.1.x (Doc typos.)
* :ghpull:`13800`: Doc typos.
* :ghpull:`13806`: Backport PR #13771 on branch v3.1.x (patches.Arc docstring update #13759)
* :ghpull:`13804`: Backport PR #13766 on branch v3.1.x (Search for fonts in XDG directory as well.)
* :ghpull:`13771`: patches.Arc docstring update #13759
* :ghpull:`13766`: Search for fonts in XDG directory as well.
* :ghpull:`13794`: Backport PR #13695 on branch v3.1.x (numpydocify transform_angles.)
* :ghpull:`13793`: Backport PR #13762 on branch v3.1.x (Cleanup marker_reference example.)
* :ghpull:`13792`: Backport PR #13789 on branch v3.1.x (BUG: Fix function signature mismatch for set_clim)
* :ghpull:`13791`: Backport PR #13787 on branch v3.1.x (Fix failure to import matplotlib.animation on Windows.)
* :ghpull:`13695`: numpydocify transform_angles.
* :ghpull:`13762`: Cleanup marker_reference example.
* :ghpull:`13789`: BUG: Fix function signature mismatch for set_clim
* :ghpull:`13787`: Fix failure to import matplotlib.animation on Windows.
* :ghpull:`13781`: Backport PR #13777 on branch v3.1.x (Use class-based directive for mathmpl sphinxext.)
* :ghpull:`13790`: Backport PR #13564 on branch v3.1.x (Add an option to log progress while saving animations)
* :ghpull:`13564`: Add an option to log progress while saving animations
* :ghpull:`13777`: Use class-based directive for mathmpl sphinxext.
* :ghpull:`13765`: Backport PR #13761 on branch v3.1.x (Deprecate verbose-related rcParams.)
* :ghpull:`13761`: Deprecate verbose-related rcParams.
* :ghpull:`13760`: Backport PR #13719 on branch v3.1.x (Doc: Update timeline example)
* :ghpull:`13704`: Backport PR #13021 on branch v3.1.x (Undesirable behaviour of MixedModeRenderer)
* :ghpull:`13758`: Backport PR #13674 on branch v3.1.x (Preserve whitespace in svg output.)
* :ghpull:`13719`: Doc: Update timeline example
* :ghpull:`13674`: Preserve whitespace in svg output.
* :ghpull:`13755`: Backport PR #13741 on branch v3.1.x (FIX: make title move above ticklabels)
* :ghpull:`13754`: Backport PR #13712 on branch v3.1.x (Deprecate NavigationToolbar2QT.adj_window (unused and always None).)
* :ghpull:`13741`: FIX: make title move above ticklabels
* :ghpull:`13712`: Deprecate NavigationToolbar2QT.adj_window (unused and always None).
* :ghpull:`13752`: Backport PR #13732 on branch v3.1.x (Fix doc markup.)
* :ghpull:`13753`: Backport PR #13751 on branch v3.1.x (DOC/FIX: try merging comments)
* :ghpull:`13751`: DOC/FIX: try merging comments
* :ghpull:`13732`: Fix doc markup.
* :ghpull:`13750`: Backport PR #13743 on branch v3.1.x (Fix doc warning)
* :ghpull:`13743`: Fix doc warning
* :ghpull:`13747`: Backport PR #13745 on branch v3.1.x (Fix stem(use_line_collection))
* :ghpull:`13748`: Backport PR #13716 on branch v3.1.x (Kill attributes that are never used/updated.)
* :ghpull:`13716`: Kill attributes that are never used/updated.
* :ghpull:`13745`: Fix stem(use_line_collection)
* :ghpull:`13710`: TST: only test agg_filter extensions with baseline images
* :ghpull:`13709`: Backport PR #8690 on branch v3.1.x
* :ghpull:`13707`: Backport PR #12760 on branch v3.1.x (Deduplicate implementation of per-backend Tools.)
* :ghpull:`13706`: Backport PR #13689 on branch v3.1.x (BUG: fix scaling of quiverkey when quiver scale_units='xy')
* :ghpull:`13705`: Backport PR #12419 on branch v3.1.x (Add DivergingNorm (again, again, again))
* :ghpull:`13703`: Backport PR #12170 on branch v3.1.x (Deprecate considering \*args, \*\*kwargs in Timer.remove_callback.)
* :ghpull:`12760`: Deduplicate implementation of per-backend Tools.
* :ghpull:`13689`: BUG: fix scaling of quiverkey when quiver scale_units='xy'
* :ghpull:`12419`: Add DivergingNorm (again, again, again)
* :ghpull:`8690`: Adds support for rgba and rgb images to pcolorfast
* :ghpull:`13021`: Undesirable behaviour of MixedModeRenderer
* :ghpull:`12170`: Deprecate considering \*args, \*\*kwargs in Timer.remove_callback.
* :ghpull:`13700`: Backport PR #13588 on branch v3.1.x (FIX: fallback to viewlims if no data)
* :ghpull:`13694`: Backport PR #13677 on branch v3.1.x (Log all failures to extract font properties.)
* :ghpull:`13588`: FIX: fallback to viewlims if no data
* :ghpull:`13692`: Backport PR #13677 on branch v3.0.x (Log all failures to extract font properties.)
* :ghpull:`13677`: Log all failures to extract font properties.
* :ghpull:`13691`: Backport PR #13687 on branch v3.1.x (Update stem example)
* :ghpull:`13687`: Update stem example
* :ghpull:`13688`: Backport PR #13684 on branch v3.1.x (Use format_data_short to format image cursor data.)
* :ghpull:`13684`: Use format_data_short to format image cursor data.
* :ghpull:`13686`: Backport PR #13363 on branch v3.1.x (Inline iter_ticks into _update_ticks, and use that in mplot3d.)
* :ghpull:`13363`: Inline iter_ticks into _update_ticks, and use that in mplot3d.
* :ghpull:`13681`: Backport PR #13678 on branch v3.1.x (Fix font deduplication logic in createFontList.)
* :ghpull:`13678`: Fix font deduplication logic in createFontList.
* :ghpull:`13669`: Backport PR #13667 on branch v3.1.x (Fix incorrect signature in axis() doc.)
* :ghpull:`13667`: Fix incorrect signature in axis() doc.
* :ghpull:`13664`: Backport PR #12637 on branch v3.1.x (Tell IPython the correct GUI event loop to use for all backends.)
* :ghpull:`13665`: Backport PR #13601 on branch v3.1.x (Add a make-parameter-keyword-only-with-deprecation decorator.)
* :ghpull:`13601`: Add a make-parameter-keyword-only-with-deprecation decorator.
* :ghpull:`12637`: Tell IPython the correct GUI event loop to use for all backends.
* :ghpull:`13662`: Backport PR #13064 on branch v3.1.x (Don't explicitly add default include paths to Extensions)
* :ghpull:`13064`: Don't explicitly add default include paths to Extensions
* :ghpull:`13658`: Backport PR #13652 on branch v3.1.x (Fix empty FancyArrow crash)
* :ghpull:`13652`: Fix empty FancyArrow crash
* :ghpull:`13655`: Backport PR #11692 on branch v3.1.x (Deprecate frameon kwarg and rcParam to savefig.)
* :ghpull:`13654`: Backport PR #13614 on branch v3.1.x (Fix polar get window extent)
* :ghpull:`11692`: Deprecate frameon kwarg and rcParam to savefig.
* :ghpull:`13614`: Fix polar get window extent
* :ghpull:`13646`: Backport PR #13645 on branch v3.1.x (widgets.py fix examples connect -> mpl_connect)
* :ghpull:`13645`: widgets.py fix examples connect -> mpl_connect
* :ghpull:`13644`: Backport PR #13612 on branch v3.1.x (Improve Demo Text Rotation Mode)
* :ghpull:`13612`: Improve Demo Text Rotation Mode
* :ghpull:`13636`: Backport PR #13621 on branch v3.1.x (Remove ``asfileobj=False`` from a bunch of examples loading sample_data.)
* :ghpull:`13635`: Backport PR #13632 on branch v3.1.x (Clarify tick collision API change doc.)
* :ghpull:`13634`: Backport PR #13631 on branch v3.1.x (Switch deprecation of Tick.label to pending.)
* :ghpull:`13621`: Remove ``asfileobj=False`` from a bunch of examples loading sample_data.
* :ghpull:`13632`: Clarify tick collision API change doc.
* :ghpull:`13631`: Switch deprecation of Tick.label to pending.
* :ghpull:`13628`: Backport PR #13603 on branch v3.1.x
* :ghpull:`13603`: FIX: continue to bail tight layout if rect supplied
* :ghpull:`13627`: Backport PR #13622 on branch v3.1.x (Change title of named colors example)
* :ghpull:`13626`: Backport PR #13549 on branch v3.1.x (Simplify some annotation() calls in examples.)
* :ghpull:`13624`: Backport PR #13610 on branch v3.1.x (Update centered ticklabels example)
* :ghpull:`13625`: Backport PR #13611 on branch v3.1.x (Fix text position in Fancytextbox demo)
* :ghpull:`13622`: Change title of named colors example
* :ghpull:`13610`: Update centered ticklabels example
* :ghpull:`13611`: Fix text position in Fancytextbox demo
* :ghpull:`13607`: Backport PR #13605 on branch v3.1.x (Warn on attempts at semi-transparent outputs in ps backend.)
* :ghpull:`13608`: Backport PR #13602 on branch v3.1.x (Deprecate cbook.is_hashable.)
* :ghpull:`13602`: Deprecate cbook.is_hashable.
* :ghpull:`13605`: Warn on attempts at semi-transparent outputs in ps backend.
* :ghpull:`13599`: Backport PR #13590 on branch v3.1.x (Doc event loop requirements for Figure.show)
* :ghpull:`13590`: Doc event loop requirements for Figure.show
* :ghpull:`13597`: Backport PR #12359 on branch v3.1.x (ENH: Add boolean support for axis())
* :ghpull:`13594`: Backport PR #13592 on branch v3.1.x (DOC: Make canonical URLs point to versioned path.)
* :ghpull:`13592`: DOC: Make canonical URLs point to versioned path.
* :ghpull:`12359`: ENH: Add boolean support for axis()
* :ghpull:`13587`: Backport PR #13573 on branch v3.1.x (Fix mplot3d transparency)
* :ghpull:`13573`: Fix mplot3d transparency
* :ghpull:`13585`: Backport PR #13578 on branch v3.1.x (Revert invalid change in Centered Ticklabels example)
* :ghpull:`13584`: Backport PR #13582 on branch v3.1.x (Cleanup two font-related examples.)
* :ghpull:`13578`: Revert invalid change in Centered Ticklabels example
* :ghpull:`13582`: Cleanup two font-related examples.
* :ghpull:`13579`: Backport PR #13477 on branch v3.1.x (FIX: make EngFormatter respect axes.unicode_minus rcParam)
* :ghpull:`13577`: Backport PR #12832 on branch v3.1.x (Deprecate redundant log-scale transform classes.)
* :ghpull:`13477`: FIX: make EngFormatter respect axes.unicode_minus rcParam
* :ghpull:`12832`: Deprecate redundant log-scale transform classes.
* :ghpull:`13574`: Backport PR #12856 on branch v3.1.x (added property  usemathtext to EngFormatter)
* :ghpull:`12856`: added property  usemathtext to EngFormatter
* :ghpull:`13572`: Backport PR #12899 on branch v3.1.x (Small cleanups.)
* :ghpull:`13571`: Backport PR #11553 on branch v3.1.x (Improved Code for Segments Intersect)
* :ghpull:`12899`: Small cleanups.
* :ghpull:`11553`: Improved Code for Segments Intersect
* :ghpull:`13568`: Backport PR #13563 on branch v3.1.x (FIX: inverted colorbar ticks)
* :ghpull:`13563`: FIX: inverted colorbar ticks
* :ghpull:`13530`: BUG: keep the ticks when the colorbar axis is inverted
* :ghpull:`13565`: Backport PR #13550 on branch v3.1.x (Strip out Py2-compat in setupext.)
* :ghpull:`13550`: Strip out Py2-compat in setupext.
* :ghpull:`13562`: Backport PR #13560 on branch v3.1.x (Improve GridSpec doc)
* :ghpull:`13560`: Improve GridSpec doc
* :ghpull:`13558`: Backport PR #13546 on branch v3.1.x ( Modified docstring of the set_ylabel and set_xlabel)
* :ghpull:`13559`: Backport PR #12062 on branch v3.1.x (Separate alpha and rbg interpolation then recombine to fix issue11316)
* :ghpull:`13557`: Backport PR #13548 on branch v3.1.x (Deprecate TextWithDash.)
* :ghpull:`12062`: Separate alpha and rbg interpolation then recombine to fix issue11316
* :ghpull:`13546`:  Modified docstring of the set_ylabel and set_xlabel
* :ghpull:`13548`: Deprecate TextWithDash.
* :ghpull:`13549`: Simplify some annotation() calls in examples.
* :ghpull:`13552`: Backport PR #11241 on branch v3.1.x (Deprecate the MATPLOTLIBDATA environment variable.)
* :ghpull:`11241`: Deprecate the MATPLOTLIBDATA environment variable.
* :ghpull:`13547`: Backport PR #9314 on branch v3.1.x (Simplify units.Registry.get_converter.)
* :ghpull:`13545`: Backport PR #13541 on branch v3.1.x (DOC: Remove mention of 'complex' mode in specgram docstring)
* :ghpull:`9314`: Simplify units.Registry.get_converter.
* :ghpull:`13541`: DOC: Remove mention of 'complex' mode in specgram docstring
* :ghpull:`13539`: Backport PR #12950 on branch v3.1.x (Inline or simplify FooFormatter.pprint_val.)
* :ghpull:`13538`: Backport PR #12748 on branch v3.1.x (Use the builtin GTK3 FileChooser rather than our custom subclass.)
* :ghpull:`13537`: Backport PR #12781 on branch v3.1.x (Lazy import of private modules)
* :ghpull:`12950`: Inline or simplify FooFormatter.pprint_val.
* :ghpull:`12748`: Use the builtin GTK3 FileChooser rather than our custom subclass.
* :ghpull:`12781`: Lazy import of private modules
* :ghpull:`11218`: fix pkg-config handling to make cross-compiling work
* :ghpull:`13531`: Backport PR #11964 on branch v3.1.x (Simplify extension setup.)
* :ghpull:`11964`: Simplify extension setup.
* :ghpull:`13529`: Backport PR #13525 on branch v3.1.x (Move some links in rst out of running text.)
* :ghpull:`13528`: Backport PR #13526 on branch v3.1.x (DOC: fix Subplot calls)
* :ghpull:`13525`: Move some links in rst out of running text.
* :ghpull:`13526`: DOC: fix Subplot calls
* :ghpull:`13523`: Backport PR #13521 on branch v3.1.x (Small cleanup to headings of 3d examples.)
* :ghpull:`13521`: Small cleanup to headings of 3d examples.
* :ghpull:`13519`: Backport PR #12716 on branch v3.1.x (FIX: return the actual ax.get_window_extent)
* :ghpull:`13518`: Backport PR #12839 on branch v3.1.x (BUG: Prevent Tick params calls from overwriting visibility without being told to)
* :ghpull:`12716`: FIX: return the actual ax.get_window_extent
* :ghpull:`12839`: BUG: Prevent Tick params calls from overwriting visibility without being told to
* :ghpull:`13517`: Fix heading hierarchy in annotation tutorial.
* :ghpull:`13516`: Backport PR #13514 on branch v3.1.x (Add missing show() at end of example.)
* :ghpull:`13514`: Add missing show() at end of example.
* :ghpull:`13512`: Backport PR #13511 on branch v3.1.x (Add missing plt.show() at end of example.)
* :ghpull:`13511`: Add missing plt.show() at end of example.
* :ghpull:`13508`: Backport PR #13413 on branch v3.1.x (Simplify decade up- and down-rounding, and symmetrize expansion of degenerate log scales.)
* :ghpull:`13509`: Backport PR #13492 on branch v3.1.x (Doc more release updates)
* :ghpull:`13492`: Doc more release updates
* :ghpull:`13413`: Simplify decade up- and down-rounding, and symmetrize expansion of degenerate log scales.
* :ghpull:`13507`: Backport PR #13488 on branch v3.1.x (Animation:  interactive zoom/pan with blitting does not work)
* :ghpull:`13488`: Animation:  interactive zoom/pan with blitting does not work
* :ghpull:`13505`: Backport PR #13459 on branch v3.1.x (Document histogramming pre-binned data.)
* :ghpull:`13503`: Backport PR #10776 on branch v3.1.x (fix FancyArrowPatch picker fails depending on arrowstyle)
* :ghpull:`13504`: Backport PR #13123 on branch v3.1.x (Add shading to Axes3D.voxels, and enable it by default)
* :ghpull:`13502`: Backport PR #13180 on branch v3.1.x (Various TextPath cleanups.)
* :ghpull:`13459`: Document histogramming pre-binned data.
* :ghpull:`13501`: Backport PR #13209 on branch v3.1.x (Deprecate support for (n, 1)-shaped error arrays in errorbar().)
* :ghpull:`13500`: Backport PR #12763 on branch v3.1.x (Remove deprecated rcParams.)
* :ghpull:`13123`: Add shading to Axes3D.voxels, and enable it by default
* :ghpull:`13499`: Backport PR #13303 on branch v3.1.x (Unify checking of executable info.)
* :ghpull:`10776`: fix FancyArrowPatch picker fails depending on arrowstyle
* :ghpull:`13180`: Various TextPath cleanups.
* :ghpull:`13498`: Backport PR #13314 on branch v3.1.x (Move major/minor tick overstrike logic to Axis.)
* :ghpull:`13209`: Deprecate support for (n, 1)-shaped error arrays in errorbar().
* :ghpull:`12763`: Remove deprecated rcParams.
* :ghpull:`13303`: Unify checking of executable info.
* :ghpull:`13497`: Backport PR #13057 on branch v3.1.x (Simplify callable(self._contains) checks)
* :ghpull:`13314`: Move major/minor tick overstrike logic to Axis.
* :ghpull:`13057`: Simplify callable(self._contains) checks
* :ghpull:`13496`: Backport PR #13465 on branch v3.1.x (FIX: polar set_rlim allow bottom-only call)
* :ghpull:`13465`: FIX: polar set_rlim allow bottom-only call
* :ghpull:`13495`: Backport PR #12232 on branch v3.1.x (Add helper function to check that an argument is in a list of strings.)
* :ghpull:`12232`: Add helper function to check that an argument is in a list of strings.
* :ghpull:`11708`: Revert "Skip wx interactive tests on OSX."
* :ghpull:`13062`: Update FAQ re: batch/webserver use.
* :ghpull:`12904`: Support forward/backward mouse buttons
* :ghpull:`12150`: Deprecate \stackrel.
* :ghpull:`13449`: Let boxplot() defer rcParams application to bxp()
* :ghpull:`13425`: API: un-deprecate keyword only args to set_xlim, set_ylim
* :ghpull:`13447`: Update axes_grid docs
* :ghpull:`13473`: Deprecate backend_wx.IDLE_DELAY.
* :ghpull:`13476`: Add font to pyplot.xkcd()
* :ghpull:`13475`: Cleanup titles of embedding examples.
* :ghpull:`13468`: Suppress chaining of cache lookup failure in color conversion.
* :ghpull:`13467`: Add "c" shorthand for "color" for the Text class.
* :ghpull:`13398`: FIX: let pandas IndexInt64 work for boxplot
* :ghpull:`13375`: Improve Axes selection in Qt figure options.
* :ghpull:`13421`: DOC: update release guide
* :ghpull:`13275`: Simple logging interface.
* :ghpull:`13427`: Simplify check for tight-bbox finiteness.
* :ghpull:`13444`: Allow constructing boxplots over multiple calls.
* :ghpull:`13385`: Remove/rework uses of np.where where possible.
* :ghpull:`13441`: Make AFM parser both more compliant and less strict.
* :ghpull:`13384`: Replace np.compress by boolean indexing.
* :ghpull:`13422`: Clarify IndexError for out-of-bounds indexing of gridspec.
* :ghpull:`13443`: Remove some outdated comments from rcsetup.py.
* :ghpull:`13357`: Inherit some docstrings in backend code.
* :ghpull:`12380`: Stem speedup2
* :ghpull:`13368`: FIX: Fix shape of hist output when input is multidimensional empty list
* :ghpull:`5590`: [mpl_toolkits] Fix picking for things drawn on parasite axes
* :ghpull:`13323`: Move the call to Formatter.set_locs into Formatter.format_ticks.
* :ghpull:`13424`: Deprecate Quiver.color in favor of Quiver.get_facecolor().
* :ghpull:`13434`: More smoketesting of pcolorfast.
* :ghpull:`13395`: Cleanup demo_curvelinear_grid.
* :ghpull:`13411`: Deemphasize numeric locations for legend() in docs.
* :ghpull:`13419`: FIX: secondary_axis resize
* :ghpull:`13020`: Deprecate proj3d.mod.
* :ghpull:`13030`: Deprecate internal functions exposed in the public API of mplot3d
* :ghpull:`13408`: test_figure style fixes.
* :ghpull:`11127`: Legend for Scatter
* :ghpull:`11855`: Adding the possible to add full command line in animation
* :ghpull:`13409`: Add nonsingular to the locator base class, and use it in set_*lim too.
* :ghpull:`11859`: ENH: add secondary x/y axis
* :ghpull:`13235`: Vectorize mplot3d.art3d.zalpha.
* :ghpull:`10411`: New "accepts units" decorator
* :ghpull:`13403`: FIX: remove idle_event
* :ghpull:`13069`: 5 minor divisions when major ticks are 2.5 units apart
* :ghpull:`13402`: Fix empty reshape2d
* :ghpull:`11683`: Reuse axes_grid1's AxisDict in axisartist, instead of duplicating it.
* :ghpull:`12141`: Let digits toggle axes nav only if they correspond to an existing axes.
* :ghpull:`9845`: Add inaxes method to FigureCanvas to check whether point is in an axes.
* :ghpull:`13396`: mpl_toolkits style fixes.
* :ghpull:`11497`: Make CI fail if interactive toolkits can't be tested
* :ghpull:`11595`: test doc rendering
* :ghpull:`13393`: Deprecate Spine.is_frame_like.
* :ghpull:`13391`: Remove colour specification from some examples
* :ghpull:`13386`: Replace use of np.<ufunc> by operators (</&/\|).
* :ghpull:`13389`: Inherit more docstrings.
* :ghpull:`13387`: Fix regression in docstring.dedent_interpd.
* :ghpull:`13383`: Replace np.take by normal indexing.
* :ghpull:`13381`: Avoid unneeded copies from flatten().
* :ghpull:`13354`: Properly deprecate non-1D inputs to pie().
* :ghpull:`13379`: Remove citation entry from FAQ.
* :ghpull:`13380`: Minor simplifications to scatter3d.
* :ghpull:`13173`: Decorator for deleting a parameter with a deprecation period.
* :ghpull:`8205`: [MRG+1] plot_date() after axhline() doesn't rescale axes
* :ghpull:`11027`: Specify custom tick space heuristic in MaxNLocator
* :ghpull:`13262`: Shorten setupext and remove uninformative build log entries.
* :ghpull:`13377`: Add private helper to internally suppress deprecations.
* :ghpull:`13376`: Undeprecate case-insensitive "long" colornames.
* :ghpull:`13373`: Deprecate axis3d.Axis.get_tick_positions.
* :ghpull:`13362`: Kill the unused, private _get_pixel_distance_along_axis.
* :ghpull:`12772`: Improve plot() docstring.
* :ghpull:`13359`: DOC: change language a bit
* :ghpull:`13351`: Fix: Log Colorbar minorticks_off reverted if ticks set
* :ghpull:`13356`: More spelling fixes.
* :ghpull:`13125`: Simplify and tighten the docstring handling API.
* :ghpull:`13346`: Simplify parsing of tuple in C extension code.
* :ghpull:`13282`: MAINT install of pinned vers for travis
* :ghpull:`13234`: FIX: allow colorbar mappable norm to change and do right thing
* :ghpull:`13269`: Rework a bit axes addition.
* :ghpull:`13330`: Add Axis.get_inverted and Axis.set_inverted.
* :ghpull:`13117`: Cleanup matplotlib.use
* :ghpull:`13335`: Update and factor out Axis.get_tick_positions.
* :ghpull:`13324`: Cleanup ScalarFormatter; preparatory to moving it to format_ticks.
* :ghpull:`13322`: Update Axis docs
* :ghpull:`13342`: Update some (mostly internal) docstrings in image.py.
* :ghpull:`11848`: Country specific characters in Windows user folder name when locating .tfm-file
* :ghpull:`13309`: bezier cleanups.
* :ghpull:`13334`: Inherit some docstrings.
* :ghpull:`13332`: Rewrite convert_to_string using std::string
* :ghpull:`13336`: Update imshow docs.
* :ghpull:`13331`: Try forcing font cache rebuild in flaky ttc test.
* :ghpull:`12105`: API: make MaxNLocator trim out-of-view ticks before returning
* :ghpull:`13329`: Pin flake8<3.7 to mitigate issues with flake8-per-file-ignores
* :ghpull:`13319`: Deprecate dates.{str,bytes}pdate2num.
* :ghpull:`13320`: Kill some private, unused functions in dates.py.
* :ghpull:`12909`: Let Formatters format all ticks at once.
* :ghpull:`13313`: Better explanation of ticks
* :ghpull:`13310`: Replace \*kw by \*args.
* :ghpull:`13285`: Defer checking of tex install to when it is actually used.
* :ghpull:`13128`: Parameter-renaming decorator
* :ghpull:`13307`: Spelling fixes.
* :ghpull:`13304`: TST: deregister pandas
* :ghpull:`13300`: Trivial bezier cleanups.
* :ghpull:`11664`: FIX: clean up unit conversion unpacking of data, particularly for dates and pandas series
* :ghpull:`9639`: Unify querying of executable versions
* :ghpull:`13224`: numpydocify (some of) mpl_toolkits.
* :ghpull:`13301`: Replace np.empty + ndarray.fill by np.full.
* :ghpull:`13229`: Prevent exception when running animation on Agg backend.
* :ghpull:`13263`: In imsave()'s Pillow-handled case, don't create a temporary figure.
* :ghpull:`13294`: Simplify some calculations in polar.py.
* :ghpull:`13295`: Kill some commented-out code.
* :ghpull:`13298`: Add note about thread safety to FAQ.
* :ghpull:`13299`: Don't emit a non-GUI warning when building the docs on Linux.
* :ghpull:`13297`: Minor cleanup to OSX FAQ.
* :ghpull:`13283`: Fix doc style in add_gridspec()
* :ghpull:`13129`: ENH: add a user-friendly verbose interface
* :ghpull:`13279`: Remove a useless catch_warnings() from example.
* :ghpull:`13268`: Select RadioButtons by closest in position.
* :ghpull:`13271`: Fix animation speed in double_pendulum example
* :ghpull:`13265`: Allow turning off minor ticks on Colorbar with LogNorm
* :ghpull:`13260`: Improve docs for format determination in savefig()/imsave().
* :ghpull:`12379`: MAINT Use np.full when possible
* :ghpull:`12905`: Add optional parameter use_default_template to rc_file()
* :ghpull:`13218`: Fix checking of 'labels' argument to Sankey.add.
* :ghpull:`13256`: DOC: reject MEP25 due to being stalled
* :ghpull:`13255`: TST pandas support bar
* :ghpull:`13251`: DEBUG-log font-matching results, and print failing logs on CI.
* :ghpull:`12818`: Enh arbitrary scale
* :ghpull:`13187`: FIX: bar mixed units, allow ValueError as well
* :ghpull:`13232`: Fix incorrect kwarg being passed to TextPath.
* :ghpull:`13250`: Replace safezip() by more informative error message in errorbar().
* :ghpull:`13239`: Improve sankey logging.
* :ghpull:`13247`: Simplify and optimize png writing in backend_pdf.
* :ghpull:`12455`: Warn when "best" loc of legend is used with lots of data
* :ghpull:`13233`: Remove warning in image_annotated_heatmap, and numpydocify it.
* :ghpull:`13248`: Remove an unused local variable in backend_gtk3.
* :ghpull:`13249`: Deprecate an unused "internal" API.
* :ghpull:`13243`: Rewrite subplots_demo
* :ghpull:`13240`: FIX: spelling error of local variable in category
* :ghpull:`13026`: MNT: add a logging call if a categorical string array is all convertible
* :ghpull:`13225`: Fix a warning in the doc build.
* :ghpull:`13227`: Make color lowercase in example to avoid warning.
* :ghpull:`13217`: numpydocify Sankey.add.
* :ghpull:`10209`: Various backend cleanups.
* :ghpull:`13113`: Globally cache single TexManager instances.
* :ghpull:`13213`: Broadcast 'orientations' arg to Sankey.add.
* :ghpull:`13219`: Fix some backend_bases docstrings.
* :ghpull:`13214`: Reformat Sankey exceptions.
* :ghpull:`13211`: Deprecate case-insensitive colors.
* :ghpull:`13210`: Suppress a warning in the test suite.
* :ghpull:`13189`: Remove cairo-based backends from backend fallback.
* :ghpull:`13207`: Allow saving PNGs through Pillow instead of the builtin _png module.
* :ghpull:`13124`: Simplify parsing of errorbar input.
* :ghpull:`13162`: DOC: better argcheck bar
* :ghpull:`8531`: Added compression option to save TIFF images
* :ghpull:`13094`: Allow passing arguments to PIL.Image.save().
* :ghpull:`13202`: Avoid private API in some examples.
* :ghpull:`13197`: Cleanup the text of two mpl_toolkits examples.
* :ghpull:`13198`: Cleanup SkewT example.
* :ghpull:`11914`: Remove the system_monitor example.
* :ghpull:`13196`: Deemphasize comment about extremely old Matplotlib versions in example.
* :ghpull:`13190`: Show returncode when subprocess test fails
* :ghpull:`13163`: Add explanatory comment to annotation box example
* :ghpull:`13104`: Remove some more 1-tuples.
* :ghpull:`13105`: Make GridSpec.update docstring match behavior.
* :ghpull:`13127`: Deprecate add_subplot(<no positional args>) silently doing nothing.
* :ghpull:`13166`: Simplify Text.get_usetex.
* :ghpull:`13188`: Remove an outdated doc point regarding backend selection.
* :ghpull:`13107`: Cleanup BboxBase docstrings.
* :ghpull:`13108`: Capitalize some docstrings.
* :ghpull:`13115`: Check for sphinx_copybutton when building the docs
* :ghpull:`13151`: Update RadioButtons docs numpydoc style
* :ghpull:`13178`: Remove :func: markup from mlab docstrings.
* :ghpull:`7461`: [WIP] add matrix checking function for quiver input
* :ghpull:`13089`: Ensure that arguments to quiver() are not matrices.
* :ghpull:`13179`: Avoid calling a deprecated API in axis_artist.
* :ghpull:`13170`: Don't try to find TeX-only fonts when layouting TeX text.
* :ghpull:`12957`: Search also for user fonts on Windows (#12954)
* :ghpull:`12951`: Make Text._get_layout simpler to follow.
* :ghpull:`11385`: Add a get_zaxis method for 3d axes.
* :ghpull:`13172`: Hyperlink DOIs to preferred resolver
* :ghpull:`13171`: Document how to make colorbars "without" a ScalarMappable.
* :ghpull:`12903`: FIX: (broken)bar(h) math before units
* :ghpull:`13167`: Typos on subplot comments and example
* :ghpull:`13005`: Improve error messages for unit conversion
* :ghpull:`13147`: Extend joinstyle example
* :ghpull:`13165`: Change doc string for Axes.arrow()
* :ghpull:`13155`: Let ffmpeg report errors.
* :ghpull:`13149`: Update errorbar limits example
* :ghpull:`13074`: Move _windowing extension into _tkagg.
* :ghpull:`13146`: Remove an outdated comment in backend_wx.
* :ghpull:`13126`: FIX: minor log ticks overwrite
* :ghpull:`13148`: Update example Step Demo
* :ghpull:`13138`: API: Use class-based directive in sphinxext
* :ghpull:`11894`: add ``cache_frame_data`` kwarg into ``FuncAnimation``. fixes #8528.
* :ghpull:`13136`: Small cleanups.
* :ghpull:`13140`: Remove an "cannot show figure in agg" warning in test suite.
* :ghpull:`13134`: Simplify color conversion backcompat shim.
* :ghpull:`13141`: Unpin pytest (pytest-cov's latest release is compatible with it).
* :ghpull:`13133`: Simplify the polys3d example.
* :ghpull:`12158`: MNT: simplify valid tick logic
* :ghpull:`9867`: Factor out common code between pdf and ps backends.
* :ghpull:`10111`: Add set_data_3d and get_data_3d to Line3d
* :ghpull:`12245`: Remove (some) features deprecated in mpl2.2
* :ghpull:`13119`: Deprecate TextToPath.glyph_to_path.
* :ghpull:`13122`: Pin pytest<4.1 to unbreak CI tests
* :ghpull:`13100`: Restore the font cache on Travis.
* :ghpull:`12792`: BUG: Ensure that distinct polygon collections are shaded identically
* :ghpull:`13070`: cairo backend: default to pycairo
* :ghpull:`13114`: BUG: calculate colorbar boundaries correctly from values
* :ghpull:`13111`: Delete an unused private method.
* :ghpull:`10841`: ENH: new date formatter
* :ghpull:`13093`: Remove unused fontconfig conf file.
* :ghpull:`13063`: Use default colour cycle in more examples
* :ghpull:`13103`: Remove tight_bbox_test example.
* :ghpull:`13097`: Replace 1-tuples by scalars where possible.
* :ghpull:`13027`: Qt5 reset signals after non-interactive plotting
* :ghpull:`9787`: Support (first font of) TTC files.
* :ghpull:`11780`: ENH: Allow arbitrary coordinates for ConnectionPatch
* :ghpull:`12943`: Update the font_table example.
* :ghpull:`13091`: Improve MouseEvent str().
* :ghpull:`13095`: Remove a duplicate attribute setting.
* :ghpull:`13090`: Cleanup unused non-public imports.
* :ghpull:`13060`: Move doc-requirements from root folder
* :ghpull:`13078`: Convert streamplot to numpydoc
* :ghpull:`13088`: Don't use deprecated np.random.random_integers.
* :ghpull:`13073`: Drop pytest version check in setupext.py.
* :ghpull:`12933`: Deprecate backend_pgf.LatexManagerFactory.
* :ghpull:`12969`: Clarify the implementation of _process_plot_var_args.
* :ghpull:`12472`: Make FontManager.defaultFont a property, to avoid hardcoding the prefix.
* :ghpull:`11806`: Allow to not draw the labels on pie chart
* :ghpull:`11983`: Simplify version checks for freetype and libpng.
* :ghpull:`13050`: FIX: always eraseRect in Qt widget
* :ghpull:`13065`: FIX: print out the correct ip address when starting webagg
* :ghpull:`13061`: Make examples that load msft.csv robust against locale changes.
* :ghpull:`13042`: cairo: remove the append_path() fast path
* :ghpull:`13058`: pathlibify/cleanup triage_tests.py.
* :ghpull:`12995`: Don't split creation of deprecation message and choice of warning class.
* :ghpull:`12998`: Init MaxNLocator params only once
* :ghpull:`11691`: Make Figure.frameon a thin wrapper for the patch visibility.
* :ghpull:`11735`: Change {FigureCanvasAgg,RendererAgg}.buffer_rgba to return a memoryview.
* :ghpull:`12831`: Reuse scale from sharing axis when calling cla().
* :ghpull:`12962`: Deprecate setting the same property under two different aliases.
* :ghpull:`12973`: Fix item check for pandas Series
* :ghpull:`13049`: Add boxplot.flierprops.markeredgewidth rcParam
* :ghpull:`13048`: Fix section names for numpydoc
* :ghpull:`10928`: Simplify (quite a bit...) _preprocess_data
* :ghpull:`13039`: Speed up Path.iter_segments()
* :ghpull:`12992`: Adding rcParams[‘scatter.edgecolors’] defaulting to ‘face’
* :ghpull:`13014`: Drop pgi support for the GTK3 backend
* :ghpull:`12215`: Cleanup initialization in text()
* :ghpull:`13029`: Fix vertical alignment of text
* :ghpull:`12968`: Simpler and stricter process_plot_format.
* :ghpull:`12989`: Avoid spamming tests with warnings re: deprecation of pprint_val.
* :ghpull:`13032`: fix typo in docstring in ``axis_artist.py``
* :ghpull:`13025`: MNT: add one more alias for tacaswell to mailmap
* :ghpull:`13010`: Fix a format error in documenting_mpl.rst
* :ghpull:`12997`: Add sphinx-copybutton to docs
* :ghpull:`12422`: Scatter color: moving #10809 forward
* :ghpull:`12999`: Format MaxNLocator with numpydoc
* :ghpull:`12991`: Canonicalize weights extracted for AFM fonts.
* :ghpull:`12955`: Cleanup cursor_demo.
* :ghpull:`12984`: Cleanup GTK examples.
* :ghpull:`12986`: Minor cleanup to double_pendulum example.
* :ghpull:`12959`: Update the documentation of Cursor
* :ghpull:`12945`: Correctly get weight & style hints from certain newer Microsoft fonts
* :ghpull:`12976`: ENH: replace deprecated numpy header
* :ghpull:`12975`: Fail-fast when trying to run tests with too-old pytest.
* :ghpull:`12970`: Minor simplifications.
* :ghpull:`12974`: Remove some checks for Py<3.6 in the test suite.
* :ghpull:`12779`: Include scatter plots in Qt figure options editor.
* :ghpull:`12459`: Improve formatting of imshow() cursor data when a colorbar exists.
* :ghpull:`12927`: MAINT: Correctly handle empty lists in zip unpacking in mplot3d.art3d
* :ghpull:`12919`: Suppress deprecation warning when testing drawstyle conflict
* :ghpull:`12956`: Misc. cleanups.
* :ghpull:`12924`: Deprecate public use of Formatter.pprint_val.
* :ghpull:`12947`: Support ~ as nonbreaking space in mathtext.
* :ghpull:`12944`: Fix the title of testing_api
* :ghpull:`12136`: MAINT: Unify calculation of normal vectors from polygons
* :ghpull:`12880`: More table documentation
* :ghpull:`12940`: Avoid pyplot in showcase examples.
* :ghpull:`12935`: os.PathLike exists on all supported Pythons now.
* :ghpull:`12936`: Minor updates following bump to Py3.6+.
* :ghpull:`12932`: Simplify argument checking in Table.__getitem__.
* :ghpull:`12930`: Shorten an argument check.
* :ghpull:`12538`: MNT: drop 3.5 testing for 3.1 branch
* :ghpull:`12868`: Simplify use of Path._fast_from_codes_and_verts.
* :ghpull:`12300`: API: Polar: allow flipped y/rlims....
* :ghpull:`12861`: Don't use deprecated wx.NewId().
* :ghpull:`12908`: Allow all valid hist.bins strings to be set in the rcparams
* :ghpull:`12902`: Kill dead code in textpath.
* :ghpull:`12885`: Improve margins in formlayout
* :ghpull:`12877`: fooImage -> foo_image in testing/compare.py
* :ghpull:`12845`: Deprecate silent dropping of unknown arguments to TextPath().
* :ghpull:`12852`: Cleanup collections docs.
* :ghpull:`12888`: Properly enable forward/backward buttons on GTK3
* :ghpull:`12865`: Avoid 1-tick or 0-tick log-scaled axis.
* :ghpull:`12844`: Remove unused, private _process_text_args.
* :ghpull:`12881`: Fix string comparison
* :ghpull:`12863`: FIX: translate timedeltas in _to_ordinalf
* :ghpull:`12640`: Introduce MouseButton enum for MouseEvent.
* :ghpull:`12897`: Reword a bit the contour docs.
* :ghpull:`12898`: Validate rcParams["image.origin"].
* :ghpull:`12882`: Write error messages to logger instead of stderr
* :ghpull:`12889`: Deprecate public access to the vendored formlayout module.
* :ghpull:`12891`: Add Azure Pipelines build badge
* :ghpull:`12883`: MAINT Use list comprehension
* :ghpull:`12886`: Properly enable forward/backward buttons on Qt
* :ghpull:`12858`: Bump oldest supported numpy to 1.11.
* :ghpull:`12876`: Fix a typo
* :ghpull:`12739`: make Axes._parse_scatter_color_args static
* :ghpull:`12846`: Deprecate Path.has_nonfinite.
* :ghpull:`12829`: Remove unused variables
* :ghpull:`12872`: Inline references to RendererPS in backend_ps.
* :ghpull:`12800`: documenting dtype of hist counts
* :ghpull:`12842`: Fix message in nbagg connection_info()
* :ghpull:`12855`: Cleanup axes/_base.py.
* :ghpull:`12826`: Minor code cleanup
* :ghpull:`12866`: Simplify stride calculations in loglocator.
* :ghpull:`12867`: Drop compat code for outdated MSVC.
* :ghpull:`12218`: Improve table docs
* :ghpull:`12847`: correctly format ticklabels when EngFormatter is used with usetex = True
* :ghpull:`12851`: Keep Collections and Patches property aliases in sync.
* :ghpull:`12849`: Update docstrings in path.py, and small cleanups.
* :ghpull:`12805`: Don't insert spurious newlines by joining tex.preamble.
* :ghpull:`12827`: Remove unused imports
* :ghpull:`12560`: Add matplotlib.testing to the documentation
* :ghpull:`12821`: MNT: remove debug from update_title_pos
* :ghpull:`12764`: Cleanup Renderer/GraphicsContext docs.
* :ghpull:`12759`: Warn on FreeType missing glyphs.
* :ghpull:`12799`: Reword some colorbar docs.
* :ghpull:`12633`: Added support for MacOSX backend for PyPy
* :ghpull:`12798`: Replace assignments to array.shape by calls to reshape().
* :ghpull:`11851`: Simpler check for whether a Framework Python build is being used.
* :ghpull:`12259`: BUG: Fix face orientations of bar3d
* :ghpull:`12565`: Make FontManager.score_weight less lenient.
* :ghpull:`12674`: Allow "real" LaTeX code for pgf.preamble in matplotlibrc
* :ghpull:`12770`: Simplify implementation of FontProperties.copy().
* :ghpull:`12753`: MNT: remove _hold shims to support basemap + cartopy
* :ghpull:`12450`: Attach a FigureCanvasBase by default to Figures.
* :ghpull:`12643`: Allow unit input to FancyArrowPatch
* :ghpull:`12767`: Make colorbars constructible with dataless ScalarMappables.
* :ghpull:`12526`: Rename jquery files
* :ghpull:`12552`: Update docs for writing image comparison tests.
* :ghpull:`12746`: Use skipif, not xfail, for uncomparable image formats.
* :ghpull:`12747`: Prefer log.warning("%s", ...) to log.warning("%s" % ...).
* :ghpull:`11753`: FIX: Apply aspect before drawing starts
* :ghpull:`12749`: Move toolmanager warning from logging to warning.
* :ghpull:`12598`: Support Cn colors with n>=10.
* :ghpull:`12727`: Reorder API docs: separate file per module
* :ghpull:`12738`: Add unobtrusive depreaction note to the first line of the docstring.
* :ghpull:`11663`: Refactor color parsing of Axes.scatter
* :ghpull:`12736`: Move deprecation note to end of docstring
* :ghpull:`12704`: Rename tkinter import from Tk to tk.
* :ghpull:`12715`: Cleanup dviread.
* :ghpull:`12717`: Delete some ``if __name__ == "__main__"`` clauses.
* :ghpull:`10575`: FIX patch.update_from to also copy _original_edge/facecolor
* :ghpull:`12537`: Improve error message on failing test_pyplot_up_to_date
* :ghpull:`12721`: Make get_scale_docs() internal
* :ghpull:`12706`: Extend sphinx Makefile to cleanup completely
* :ghpull:`12481`: Warn if plot_surface Z values contain NaN
* :ghpull:`12685`: Make ticks in demo_axes_rgb.py visible
* :ghpull:`12523`: Run flake8 before pytest on travis
* :ghpull:`12691`: DOC: Link to "How to make a PR" tutorials as badge and in contributing
* :ghpull:`11974`: Make code match comment in sankey.
* :ghpull:`12440`: Make arguments to @deprecated/warn_deprecated keyword-only.
* :ghpull:`12470`: Update AutoDateFormatter with locator
* :ghpull:`12586`: Improve linestyles example
* :ghpull:`12006`: Replace warnings.warn with cbook._warn_external or logging.warning
* :ghpull:`12659`: Add note that developer discussions are private
* :ghpull:`12543`: Make rcsetup.py flak8 compliant
* :ghpull:`12642`: Don't silence TypeErrors in fmt_{x,y}data.
* :ghpull:`12442`: Deprecate passing drawstyle with linestyle as single string.
* :ghpull:`12625`: Shorten some docstrings.
* :ghpull:`12627`: Be a bit more stringent on invalid inputs.
* :ghpull:`12629`: Fix issue with PyPy on macOS
* :ghpull:`10933`: Remove "experimental" fontconfig font_manager backend.
* :ghpull:`12600`: Minor style fixes.
* :ghpull:`12570`: Fix mathtext tutorial for build with Sphinx 1.8.
* :ghpull:`12487`: Update docs/tests for the deprecation of aname and label1On/label2On/etc.
* :ghpull:`12521`: Improve docstring of draw_idle()
* :ghpull:`12574`: Remove some unused imports
* :ghpull:`12568`: Add note regarding builds of old Matplotlibs.
* :ghpull:`12547`: Disable sticky edge accumulation if no autoscaling.
* :ghpull:`12546`: Avoid quadratic behavior when accumulating stickies.
* :ghpull:`11789`: endless looping GIFs with PillowWriter
* :ghpull:`12525`: Fix some flake8 issues
* :ghpull:`12516`: Don't handle impossible values for ``align`` in hist()
* :ghpull:`12500`: Adjust the widths of the messages during the build.
* :ghpull:`12492`: Simplify radar_chart example.
* :ghpull:`11984`: Strip out pkg-config machinery for agg and libqhull.
* :ghpull:`12463`: Document Artist.cursor_data() parameter
* :ghpull:`12482`: Test slider orientation
* :ghpull:`12317`: Always install mpl_toolkits.
* :ghpull:`12246`: Be less tolerant of broken installs.
* :ghpull:`12477`: Use \N{MICRO SIGN} instead of \N{GREEK SMALL LETTER MU} in EngFormatter.
* :ghpull:`12483`: Kill FontManager.update_fonts.
* :ghpull:`12474`: Throw ValueError when irregularly gridded data is passed to streamplot.
* :ghpull:`12466`: np.fromstring -> np.frombuffer.
* :ghpull:`12369`: Improved exception handling on animation failure
* :ghpull:`12460`: Deprecate RendererBase.strip_math.
* :ghpull:`12453`: Rollback erroneous commit to whats_new.rst from #10746
* :ghpull:`12452`: Minor updates to the FAQ.
* :ghpull:`10746`: Adjusted matplotlib.widgets.Slider to have optional vertical orientatation
* :ghpull:`12441`: Get rid of a signed-compare warning.
* :ghpull:`12430`: Deprecate Axes3D.plot_surface(shade=None)
* :ghpull:`12435`: Fix numpydoc parameter formatting
* :ghpull:`12434`: Clarify documentation for textprops keyword parameter of TextArea
* :ghpull:`12427`: Document Artist.get_cursor_data
* :ghpull:`10322`: Use np.hypot wherever possible.
* :ghpull:`10809`: Fix for scatter not showing points with valid x/y but invalid color
* :ghpull:`12423`: Minor simplifications to backend_svg.
* :ghpull:`10356`: fix detecting which artist(s) the mouse is over
* :ghpull:`10268`: Dvi caching
* :ghpull:`10238`: Call kpsewhich with more arguments at one time
* :ghpull:`10236`: Cache kpsewhich results persistently
* :ghpull:`4675`: Deprecate color keyword argument in scatter
* :ghpull:`5054`: Diverging norm
* :ghpull:`12416`: Move font cache rebuild out of exception handler
* :ghpull:`4762`: Traitlets
* :ghpull:`5414`: WIP: New FreeType wrappers
* :ghpull:`3875`: ENH: passing colors (and other optional keyword arguments) to violinplot()
* :ghpull:`1959`: PS backend optionally jpeg-compresses the embedded images
* :ghpull:`11891`: Group some print()s in backend_ps.
* :ghpull:`12165`: Remove deprecated mlab code
* :ghpull:`12387`: Update HTML animation as slider is dragged
* :ghpull:`12333`: ENH: add colorbar method to axes
* :ghpull:`10088`: Deprecate Tick.{gridOn,tick1On,label1On,...} in favor of set_visible.
* :ghpull:`12393`: Deprecate to-days converters in matplotlib dates
* :ghpull:`11232`: FIX: fix figure.set_dpi when pixel ratio not 1
* :ghpull:`12247`: Machinery for deprecating properties.
* :ghpull:`12371`: Move check for ImageMagick Windows path to bin_path().
* :ghpull:`12384`: Cleanup axislines style.
* :ghpull:`9565`: Stem performance boost
* :ghpull:`12368`: Don't use stdlib private API in animation.py.
* :ghpull:`12351`: dviread: find_tex_file: Ensure the encoding on windows
* :ghpull:`12372`: Remove two examples.
* :ghpull:`12356`: Fix stripping of CRLF on Windows.
* :ghpull:`12283`: FIX: errorbar xywhere should return ndarray
* :ghpull:`12304`: TST: Merge Qt tests into one file.
* :ghpull:`12340`: Catch test deprecation warnings for mlab.demean
* :ghpull:`12296`: Make FooConverter inherit from ConversionInterface in examples
* :ghpull:`12309`: Deduplicate implementations of FooNorm.autoscale{,_None}
* :ghpull:`7716`: [NF] Add 'truncate' and 'join' methods to colormaps.
* :ghpull:`12314`: Deprecate ``axis('normal')`` in favor of ``axis('auto')``.
* :ghpull:`12307`: Clarify missing-property error message.
* :ghpull:`12260`: Fix docs : change from issue #12191, remove "if 1:" blocks in examples
* :ghpull:`12253`: Handle utf-8 output by kpathsea on Windows.
* :ghpull:`12292`: TST: Modify the bar3d test to show three more angles
* :ghpull:`12284`: Don't try to autoscale if no data present to autoscale to
* :ghpull:`12255`: Deduplicate inherited docstrings.
* :ghpull:`12222`: Remove extraneous if 1 statements in demo_axisline_style.py
* :ghpull:`12137`:  MAINT: Vectorize bar3d
* :ghpull:`12219`: Merge OSXInstalledFonts into findSystemFonts.
* :ghpull:`12229`: Less ACCEPTS, more numpydoc.
* :ghpull:`11621`: TST: make E402 a universal flake8 ignore
* :ghpull:`12231`: CI: Speed up Appveyor repository cloning
* :ghpull:`11661`: Update blocking_input.py
* :ghpull:`12199`: Allow disabling specific mouse actions in blocking_input
* :ghpull:`12210`: Axes.tick_params() argument checking
* :ghpull:`12211`: Fix typo
* :ghpull:`12200`: Slightly clarify some invalid shape exceptions for image data.
* :ghpull:`12151`: Don't pretend @deprecated applies to classmethods.
* :ghpull:`12190`: Remove some unused variables and imports
* :ghpull:`12192`: Exclude examples from lgtm analysis
* :ghpull:`12196`: Give Carreau the ability to mention the backport bot.
* :ghpull:`12171`: Remove internal warning due to zsort deprecation
* :ghpull:`12030`: Speed up canvas redraw for GTK3Agg backend.
* :ghpull:`12156`: Cleanup the GridSpec demos.
* :ghpull:`12144`: Add explicit getters and setters for Annotation.anncoords.
* :ghpull:`12152`: Use _warn_external for deprecations warnings.
* :ghpull:`12147`: DOC: update the gh_stats code
* :ghpull:`12139`: Unbreak build re: mplot3d style.
* :ghpull:`11367`: Raise TypeError on unsupported kwargs of spy()
* :ghpull:`9990`: Fix and document lightsource argument in mplot3d
* :ghpull:`12124`: Correctly infer units from empty arrays
* :ghpull:`11994`: Cleanup unused variables and imports
* :ghpull:`12122`: MNT: re-add cbook import art3d
* :ghpull:`12086`: FIX: make MaxNLocator only follow visible ticks for order of magnitude
* :ghpull:`12032`: Remove unused imports
* :ghpull:`12093`: Correct the removal of -Wstrict-prototypes from compiler flags.
* :ghpull:`12069`: Style fixes for mplot3d.
* :ghpull:`11997`: Cleanup some axes_grid1 examples
* :ghpull:`12098`: Improve layout of HTML animation
* :ghpull:`12094`: Fine-tune logging notes in contributing.rst.
* :ghpull:`12079`: Clarifications to **im_show()** doc regarding *interpolation='none'*.
* :ghpull:`12068`: More style fixes.
* :ghpull:`11499`: FIX: layout for mixed descent multiline text objects
* :ghpull:`11921`: FIX: allow reshape 2-D to return a bare 1-d list
* :ghpull:`12070`: Avoid some uses of np.isscalar.
* :ghpull:`12067`: DOC: make Line2D docstring definition easier to find
* :ghpull:`12054`: More style fixes.
* :ghpull:`12066`: fix indentation in docstring interpolation for spy.
* :ghpull:`11931`: Remove separate autosummary_inher template.
* :ghpull:`12049`: Make Poly3DCollection.set_zsort less lenient.
* :ghpull:`12050`: Various cleanups.
* :ghpull:`12038`: Modernize ArtistInspector a bit...
* :ghpull:`12033`: DOC: formatting fixes to mplot3d
* :ghpull:`12051`: Is bool
* :ghpull:`12045`:  Fix 999.9... edge case in ticker.EngFormatter for negative numbers
* :ghpull:`12044`: Update doc on the *progressive* and *optimize* keywords in savefig
* :ghpull:`12061`: Small refactor/simplification.
* :ghpull:`12060`: INSTALL.rst fixes
* :ghpull:`12055`: Fix invalid escape in docstring.
* :ghpull:`12026`: whitespace(-mostly) style cleanup.
* :ghpull:`12043`: Deprecate get_py2exe_datafiles.
* :ghpull:`12046`: Make HTMLWriter constructor a bit more strict.
* :ghpull:`12034`: Doc markup fixes.
* :ghpull:`11972`: FIX: close mem leak for repeated draw
* :ghpull:`12024`: Fix typos
* :ghpull:`11996`: Minor javascript cleanup
* :ghpull:`11989`: Remove support for ghostscript 8.60.
* :ghpull:`12004`: Update acorr and xcorr docs to match numpy docs
* :ghpull:`11998`: No clf() needed after creating a figure
* :ghpull:`12001`: Do not use an explicit figum in plt.figure(1, ...) in simple cases
* :ghpull:`11999`: Do not use an explicit fignum plt.figure(1) in simple cases
* :ghpull:`11995`: Don't use bare except statements
* :ghpull:`11993`: DOC: fixed typos
* :ghpull:`11992`: Use pytest.warns instead of home-baked warnings capture.
* :ghpull:`11975`: Derive plt.figlegend.__doc__ from Figure.legend.__doc__.
* :ghpull:`11980`: Remove __version__numpy__; simplify dependencies check.
* :ghpull:`11982`: Remove and old keyword documentation.
* :ghpull:`11981`: Some extra typos
* :ghpull:`11979`: Fix a couple of typos.
* :ghpull:`11959`: cbook.iterable -> np.iterable.
* :ghpull:`11965`: Move the removal of the -Wstrict-prototypes flag to setup.py.
* :ghpull:`11958`: Remove unused code
* :ghpull:`11960`: Make jpl_units a bit less painful to read.
* :ghpull:`11951`: Improve Artist docstrings
* :ghpull:`11954`: No need to define _log twice in matplotlib.dates.
* :ghpull:`11948`: Minor fixes to docs and gitignore.
* :ghpull:`11777`: Avoid incorrect warning in savefig
* :ghpull:`11942`: Deprecate Artist.aname and Axes.aname
* :ghpull:`11935`: Remove ginput demo example
* :ghpull:`11939`: Improve alias signatures
* :ghpull:`11940`: Do not use aliases of properties in internal code
* :ghpull:`11941`: Fix test_large_subscript_title()
* :ghpull:`11938`: More docstring cleanup of Line2D.
* :ghpull:`11920`: Add LGTM.com code quality badge
* :ghpull:`11922`: Improve docstrings of Line2D
* :ghpull:`11924`: Minor formatting update on alias docstrings
* :ghpull:`11926`: Minor fix to ginput_demo.
* :ghpull:`11912`: BLD: update PR template for flake8
* :ghpull:`11909`: Simplify linestyle and fillstyle reference docs.
* :ghpull:`11502`: FIX: move title(s) up if subscripts hang too low.
* :ghpull:`11906`: fix format of bar_of_pie example
* :ghpull:`11741`:  Factor out common code between Patch.draw and FancyArrowPatch.draw.
* :ghpull:`11784`: Argument checking for grid()
* :ghpull:`11888`: Factor out a subprocess log-and-check helper.
* :ghpull:`11740`: Deprecate support for 3rd-party backends without set_hatch_color.
* :ghpull:`11884`: Deprecate the tk_window_focus function.
* :ghpull:`11689`: Don't cache the renderer on the Axes instance.
* :ghpull:`11698`: For property, use decorator or lambdas.
* :ghpull:`11872`: Make all builtin cmaps picklable.
* :ghpull:`11870`: More style fixes.
* :ghpull:`11873`: Remove mention of deprecated/removed methods from mlab's docstring.
* :ghpull:`11869`: Style fixes.
* :ghpull:`11874`: Remove some remnants of Py2-handling in test_rcparams.
* :ghpull:`11865`: example file for making a bar of pie chart
* :ghpull:`11868`: mathtext.py style fixes.
* :ghpull:`11854`: Accept anything that's not a directory for $MATPLOTLIBRC.
* :ghpull:`11589`: WIP ENH secondary axes:
* :ghpull:`8449`: Including Additional Metadata using the SVG Backend
* :ghpull:`11465`: ENH: optimize Collection non-affine transform to call transform once

Issues (161):

* :ghissue:`4001`: Qt5 Backend: dblclick is always False on 'mouse_release_event'
* :ghissue:`14152`: qt_compat.py performing wrong test for PyQt5
* :ghissue:`10875`: Annotation.contains and FancyArrow.contains return incorrect values
* :ghissue:`458`: JPG quality keyword in savefig
* :ghissue:`4354`: scatter not showing valid x/y points with invalid color
* :ghissue:`14113`: scatter could not raise when colors are provided but position data are empty
* :ghissue:`14003`: numpydoc 0.9 breaks doc build
* :ghissue:`14054`: ticks sometimes disappear when zooming interactively
* :ghissue:`10189`: The data decorator does not integrate well with numpydoc
* :ghissue:`14034`: pyplot plot raises ValueError when plotting NaN against datetime dates
* :ghissue:`14039`: bar plot yerr lines/caps should respect zorder
* :ghissue:`14042`: dynamic_image.py + saving animation broken
* :ghissue:`14013`: osx backend not usable with ipython/jupyter from conda?
* :ghissue:`13993`: Tests files installed by default?
* :ghissue:`13991`: MaxNLocator.default_params deprecation may break Cartopy
* :ghissue:`5045`: Axes.grid() not honoring specified "zorder" kwarg
* :ghissue:`4371`: LaTeX and PGF preambles do not allow commas
* :ghissue:`13982`: hist() no longer respects range=... when density=True
* :ghissue:`13963`: Dataless colorbars break when updated
* :ghissue:`10381`: Issue when setting scatter color in separate method call
* :ghissue:`13618`: Minor ticklabels are missing at positions of major ticks.
* :ghissue:`13880`: Adding documentation for Text.fontfamily default, set_fontfamily(None)?
* :ghissue:`13865`: Appveyor broken
* :ghissue:`8636`: plt.hist chooses improper range when using string-based bin options
* :ghissue:`7300`: weird mathtext doc markup
* :ghissue:`8862`: Replace \mathcircled by \textcircled
* :ghissue:`13759`: DOC: matplotlib.patches.Arc
* :ghissue:`13785`: Imshow gives values out of the extent
* :ghissue:`13786`: Cannot import matplotlib.animation
* :ghissue:`13561`: Progress of animation.save (for long animations)
* :ghissue:`13735`: title doesn't move for ticklables....
* :ghissue:`12175`: Example link near markevery in the "What's new in 3.0" page is malformed/broken
* :ghissue:`13713`: Boxplot xlim not correctly calculated
* :ghissue:`11070`: Add a "density" kwarg to hist2d
* :ghissue:`11337`: Cannot plot fully masked array against datetimes
* :ghissue:`10165`: Adapt stem plot
* :ghissue:`10976`: ENH: secondary axis for a x or y scale.
* :ghissue:`10763`: Cairo in 2.2.0 not working for new backends
* :ghissue:`9737`: setupext should not explicitly add /usr/{,local/}include to the include path
* :ghissue:`11217`: Crash on zero-length FancyArrow
* :ghissue:`13623`: do not cause warning in seaborn
* :ghissue:`13480`: Segfault on help('modules') command when matplotlib is installed
* :ghissue:`13604`: legend's framealpha kwarg does not apply when writing to an eps file
* :ghissue:`12311`: 'off' vs. False bug
* :ghissue:`10237`: Setting an alpha value to a Poly3DCollection
* :ghissue:`11781`: fill_between interpolation & nan issue
* :ghissue:`1077`: 3d plots with aspect='equal'
* :ghissue:`11761`: Still naming inconsistency in API on axes limits
* :ghissue:`11623`: Regression: "TypeError: Period('2000-12-31', 'D') is not a string" when a Series with date index was plotted
* :ghissue:`12655`: auto-ticks do not handle values near bounds gracefully
* :ghissue:`13487`: labelpad is not the spacing between the axis and the label
* :ghissue:`13540`: Docs for matplotlib.pyplot.specgram() reference an unsupported mode setting
* :ghissue:`8997`: Proposal: Grid arrangement by number of plots
* :ghissue:`6928`: Cannot run ``setup.py build`` with numpy master
* :ghissue:`12697`: Axes are drawn at wrong positions
* :ghissue:`13478`: FuncAnimation:  interactive zoom/pan with blitting does not work
* :ghissue:`11575`: Setting axis ticks in log scale produces duplicate tick labels.
* :ghissue:`13464`: set_rlim(bottom=...) no longer works
* :ghissue:`12628`: Write canonical example of how to use Matplotlib inside a webserver
* :ghissue:`10022`: boxplot: positions used to take Int64Index
* :ghissue:`11647`: Disable buttons in ginput
* :ghissue:`12987`: issues parsing AFM fonts
* :ghissue:`12667`: Colorbar ticks....
* :ghissue:`13137`: Travis for Python 3.7 sometimes fails due to missing font
* :ghissue:`7969`: Stem is slow and will crash if I try to close the window
* :ghissue:`13002`: Hist color kwarg broken for multiple empty datasets
* :ghissue:`5581`: [mpl_toolkits] Things drawn on parasite axes don't fire pick events
* :ghissue:`13417`: Secondary axis doesn't resize properly
* :ghissue:`8120`: Inconsistent inset_axes position between show(), savefig(format='png') and savefig(format='pdf')
* :ghissue:`8947`: Different result, slower runtime of heatmap between 2.0.0 and 2.0.1
* :ghissue:`13264`: Use of logging in matplotlib
* :ghissue:`11602`: animation error
* :ghissue:`12925`: Python pandas datetime plot xticks in unexpected location
* :ghissue:`11025`: AxesGrid ticks missing on x-axis
* :ghissue:`10974`: Examples not shown in API docs for many methods.
* :ghissue:`13392`: boxplot broken for empty inputs
* :ghissue:`12345`: Need more tests for units and errorbar
* :ghissue:`10361`: FigureCanvas.draw() with tight_layout () needs to be called twice with Matplotlib 2.1.0
* :ghissue:`11376`: Temporary styling ignores color cycle
* :ghissue:`11546`: import time
* :ghissue:`13286`: AttributeError: 'float' object has no attribute 'deg2rad'
* :ghissue:`11508`: bi-directional perceptually flat colormaps in matplotlib?
* :ghissue:`12918`: Mac shows an icon in the dock when using matplotlib.pyplot.
* :ghissue:`13339`: Log Colorbar minorticks_off reverted if ticks set...
* :ghissue:`13228`: MPL 3 + Colorbar + PowerNorm bug
* :ghissue:`13096`: Matplotlib.get_backend()/matplotlib.use() cause NSException with Anaconda
* :ghissue:`7712`: Number of ticks for dates still gives overlapping labels
* :ghissue:`9978`: General poor default formatting of datetimes on plot x-axis
* :ghissue:`13253`: imsave outputs JPEG with wrong dimension
* :ghissue:`11391`: Use data argument for scatter plotting timestamps from pandas
* :ghissue:`13145`: widgets.RadioButtons: select by closest in position
* :ghissue:`13267`: "double-pendulum" example's speed not correct / varying
* :ghissue:`13257`: Allow turning off minorticks for Colorbar with LogNorm?
* :ghissue:`13237`: Sankey basic gallery example is not rendered properly.
* :ghissue:`12836`: matplotlib.rc_file resets to default template before updating rcparams
* :ghissue:`13186`: ax.bar throws when x axis is pandas datetime
* :ghissue:`5397`: Expose compression and filter PNG options through savefig
* :ghissue:`13142`: Cannot plot bar graph with dates: "TypeError: ufunc subtract cannot use operands with types dtype('<M8[ns]') and dtype('float64')"
* :ghissue:`8530`: Feature request: TIFF LZW compression support in savefig()
* :ghissue:`13139`: font family ['serif'] not found. Falling back to DejaVu Sans
* :ghissue:`1558`: Graceful handling of a numpy matrix
* :ghissue:`12954`: Fonts installed in the user directory are not detected (Windows 1809)
* :ghissue:`3644`: Feature Request: manually set colorbar without mappable
* :ghissue:`12862`: broken_barh appears not to work with datetime/timedelta objects
* :ghissue:`11290`: ax.bar doesn't work correctly when width is a timedelta64 object
* :ghissue:`13156`: DOC: matplotlib.pyplot.arrow
* :ghissue:`12990`: Unclear error message for ``plt.xticks(names)``
* :ghissue:`12769`: Failing to save an animated graph with matplotlib.animation
* :ghissue:`13112`: LogNorm colorbar prints double tick labels after set_ticks()
* :ghissue:`13132`: BUG: matplotlib.sphinxext.plot_directive uses old function-based API
* :ghissue:`8528`: Funcanimation memory leak?
* :ghissue:`8914`: line3D set_data only takes in x and y data
* :ghissue:`8768`: One one tick in a log-scale axis
* :ghissue:`13121`: Tests fail with pytest 4.1
* :ghissue:`13098`: Likely incorrect code(?) in colorbar.py
* :ghissue:`12562`: Clean up unused imports
* :ghissue:`12106`: plt.plot does not plot anything with named arguments
* :ghissue:`5145`: Python [Error 17]No usable Temporary file name found
* :ghissue:`13012`: qt5agg image quality changes when window is out of focus
* :ghissue:`13055`: 127.0.0.1 hardcoded in webagg backend server
* :ghissue:`12971`: Pandas Series not supported as data kwarg
* :ghissue:`13022`: boxplot not showing symbols with seaborn style sheet
* :ghissue:`13028`: Bad rotation_mode/center_baseline combination even if rotation=0
* :ghissue:`12745`: Sphinx copy button for code block
* :ghissue:`12801`: scatter() should not drop data points at nonfinite coordinates
* :ghissue:`12358`: Dropping support for Py3.5 and numpy 1.10
* :ghissue:`12994`: Axes range with set_xticks with categoricals
* :ghissue:`12993`: Semantics of set_xticks for categoricals
* :ghissue:`12946`: ~ in mathrm leads to Unknown symbol: \mathrm
* :ghissue:`10704`: Add documentation for set_rlim
* :ghissue:`11202`: Using of ax.set_ylim() for polar plot leads to "posx and posy should be finite values" error
* :ghissue:`12859`: DeprecationWarning: NewId() is deprecated in wxPython.
* :ghissue:`12817`: Multiple places where Type Errors on cbook.warn_deprecated will happen
* :ghissue:`12308`: #12253 FIX: Handle utf-8 output by kpathsea on Windows -- possibly causing issues
* :ghissue:`12804`: Usetex produces preamble with one character per line
* :ghissue:`12808`: Issue with minor tick spacing in colorbar with custom Normalize class
* :ghissue:`12138`: Faces of Axes3d.bar3d are not oriented correctly
* :ghissue:`12591`: Adding FancyArrowPatch with datetime coordinates fails
* :ghissue:`11139`: "make clean" doesn't remove all the build doc files
* :ghissue:`11908`: Improve linestyle documentation
* :ghissue:`10643`: Most warnings calls do not set the stacklevel
* :ghissue:`12532`: Incorrect rendering of math symbols
* :ghissue:`11787`: Looping gifs with PillowWriter
* :ghissue:`9205`: after the animation encoder (e.g. ffmpeg) fails, the animation framework itself fails internally in various ways while trying to report the error
* :ghissue:`11154`: Unexpected behavior for Axes3D.plot_surface(shade=None)
* :ghissue:`12121`: Documentation of TextArea's fontprops keyword argument is misleading
* :ghissue:`12191`: "if 1:" blocks in examples
* :ghissue:`12107`: warnings re: deprecated pytest API with pytest 3.8
* :ghissue:`12010`: Popover over plot is very slow
* :ghissue:`12118`: Scatter: empty np.arrays with non-numeric dtypes cause TypeError
* :ghissue:`12072`: ``MaxNLocator`` changes the scientific notation exponent with different number of tick labels
* :ghissue:`11795`: Un-align animations created with to_jshtml()?
* :ghissue:`10201`: Available fonts are ignored by font_manager
* :ghissue:`12065`: Keyword *interpolation* behaving improperly while saving to SVG with **savefig()**
* :ghissue:`11498`: Test layout with big descenders and multiple lines inconsistent.
* :ghissue:`11468`: Layout managers have problems with titles containing MathText
* :ghissue:`11899`: Histogram of list of datetimes
* :ghissue:`11956`: apparent memory leak with live plotting
* :ghissue:`11587`: Missing filled contours when using contourf
* :ghissue:`11716`: errorbar pickling fails when specifying y error bars
* :ghissue:`11557`: Hoping add a drawing function 'patch'  in matplotlib
